@@ -15,7 +15,7 @@ __all__ = [
     "thai_words",
 ]
 
-from typing import Union
+from typing import FrozenSet, List, Union
 
 from pythainlp.corpus import get_corpus
 
@@ -46,7 +46,7 @@ _THAI_MALE_NAMES = set()
 _THAI_MALE_NAMES_FILENAME = "person_names_male_th.txt"
 
 
-def countries() -> frozenset:
+def countries() -> FrozenSet[str]:
     """
     Return a frozenset of country names in Thai such as "แคนาดา", "โรมาเนีย",
     "แอลจีเรีย", and "ลาว".
@@ -63,7 +63,7 @@ def countries() -> frozenset:
     return _THAI_COUNTRIES
 
 
-def provinces(details: bool = False) -> Union[frozenset, list]:
+def provinces(details: bool = False) -> Union[FrozenSet[str], List[str]]:
     """
     Return a frozenset of Thailand province names in Thai such as "กระบี่",
     "กรุงเทพมหานคร", "กาญจนบุรี", and "อุบลราชธานี".
@@ -106,12 +106,13 @@ def provinces(details: bool = False) -> Union[frozenset, list]:
     return _THAI_THAILAND_PROVINCES
 
 
-def thai_syllables() -> frozenset:
+def thai_syllables() -> FrozenSet[str]:
     """
     Return a frozenset of Thai syllables such as "กรอบ", "ก็", "๑", "โมบ",
     "โมน", "โม่ง", "กา", "ก่า", and, "ก้า".
     \n(See: `dev/pythainlp/corpus/syllables_th.txt\
     <https://github.com/PyThaiNLP/pythainlp/blob/dev/pythainlp/corpus/syllables_th.txt>`_)
+    We using thai syllables list from `KUCut <https://github.com/Thanabhat/KUCut>`_.
 
     :return: :class:`frozenset` containing syllables in Thai language.
     :rtype: :class:`frozenset`
@@ -123,7 +124,7 @@ def thai_syllables() -> frozenset:
     return _THAI_SYLLABLES
 
 
-def thai_words() -> frozenset:
+def thai_words() -> FrozenSet[str]:
     """
     Return a frozenset of Thai words such as "กติกา", "กดดัน", "พิษ",
     and "พิษภัย". \n(See: `dev/pythainlp/corpus/words_th.txt\
@@ -139,11 +140,18 @@ def thai_words() -> frozenset:
     return _THAI_WORDS
 
 
-def thai_stopwords() -> frozenset:
+def thai_stopwords() -> FrozenSet[str]:
     """
     Return a frozenset of Thai stopwords such as "มี", "ไป", "ไง", "ขณะ",
     "การ", and "ประการหนึ่ง". \n(See: `dev/pythainlp/corpus/stopwords_th.txt\
     <https://github.com/PyThaiNLP/pythainlp/blob/dev/pythainlp/corpus/stopwords_th.txt>`_)
+    We using stopword lists by thesis's เพ็ญศิริ ลี้ตระกูล.
+
+    :See Also:
+
+    เพ็ญศิริ ลี้ตระกูล . \
+    การเลือกประโยคสำคัญในการสรุปความภาษาไทยโดยใช้แบบจำลองแบบลำดับชั้น. \
+    กรุงเทพมหานคร : มหาวิทยาลัยธรรมศาสตร์; 2551.
 
     :return: :class:`frozenset` containing stopwords.
     :rtype: :class:`frozenset`
@@ -155,7 +163,7 @@ def thai_stopwords() -> frozenset:
     return _THAI_STOPWORDS
 
 
-def thai_negations() -> frozenset:
+def thai_negations() -> FrozenSet[str]:
     """
     Return a frozenset of Thai negation words including "ไม่" and "แต่".
     \n(See: `dev/pythainlp/corpus/negations_th.txt\
@@ -171,7 +179,7 @@ def thai_negations() -> frozenset:
     return _THAI_NEGATIONS
 
 
-def thai_family_names() -> frozenset:
+def thai_family_names() -> FrozenSet[str]:
     """
     Return a frozenset of Thai family names
     \n(See: `dev/pythainlp/corpus/family_names_th.txt\
@@ -187,7 +195,7 @@ def thai_family_names() -> frozenset:
     return _THAI_FAMLIY_NAMES
 
 
-def thai_female_names() -> frozenset:
+def thai_female_names() -> FrozenSet[str]:
     """
     Return a frozenset of Thai female names
     \n(See: `dev/pythainlp/corpus/person_names_female_th.txt\
@@ -203,7 +211,7 @@ def thai_female_names() -> frozenset:
     return _THAI_FEMALE_NAMES
 
 
-def thai_male_names() -> frozenset:
+def thai_male_names() -> FrozenSet[str]:
     """
     Return a frozenset of Thai male names
     \n(See: `dev/pythainlp/corpus/person_names_male_th.txt\
