@@ -6,8 +6,12 @@ Credit: Korakot Chaovavanich‎
 https://www.facebook.com/photo.php?fbid=363640477387469&set=gm.434330506948445&type=3&permPage=1
 """
 
-__all__ = ["word_freqs"]
+__all__ = [
+    "word_freqs",
+    "unigram_word_freqs"
+]
 
+from collections import defaultdict
 from typing import List, Tuple
 
 from pythainlp.corpus import get_corpus
@@ -29,3 +33,17 @@ def word_freqs() -> List[Tuple[str, int]]:
             word_freqs.append((word_freq[0], int(word_freq[1])))
 
     return word_freqs
+
+
+def unigram_word_freqs() -> defaultdict:
+    """
+    Get unigram word frequency from Thai Textbook Corpus (TTC)
+    """
+    lines = list(get_corpus(_FILENAME))
+    _word_freqs = defaultdict(int)
+    for i in lines:
+        _temp = i.strip().split("	")
+        if len(_temp) >= 2:
+            _word_freqs[_temp[0]] = int(_temp[-1])
+
+    return _word_freqs
