@@ -3,6 +3,7 @@
 Text normalization
 """
 import re
+from typing import List, Union
 import warnings
 
 from pythainlp import thai_above_vowels as above_v
@@ -10,6 +11,7 @@ from pythainlp import thai_below_vowels as below_v
 from pythainlp import thai_follow_vowels as follow_v
 from pythainlp import thai_lead_vowels as lead_v
 from pythainlp import thai_tonemarks as tonemarks
+from pythainlp.tokenize import word_tokenize
 
 
 _DANGLING_CHARS = f"{above_v}{below_v}{tonemarks}\u0e3a\u0e4c\u0e4d\u0e4e"
@@ -66,6 +68,14 @@ def remove_dangling(text: str) -> str:
     :param str text: input text
     :return: text without dangling Thai characters at the beginning
     :rtype: str
+
+    :Example:
+    ::
+
+        from pythainlp.util import remove_dangling
+
+        remove_dangling('๊ก')
+        # output: 'ก'
     """
     return _RE_REMOVE_DANGLINGS.sub("", text)
 
@@ -80,6 +90,14 @@ def remove_dup_spaces(text: str) -> str:
     :param str text: input text
     :return: text without duplicated spaces and newlines
     :rtype: str
+
+    :Example:
+    ::
+
+        from pythainlp.util import remove_dup_spaces
+
+        remove_dup_spaces('ก    ข    ค')
+        # output: 'ก ข ค'
     """
     while "  " in text:
         text = text.replace("  ", " ")
@@ -238,3 +256,45 @@ def delete_tone(text: str) -> str:
         DeprecationWarning,
     )
     return remove_tonemark(text)
+
+
+def maiyamok(sent: Union[str, List[str]]) -> List[str]:
+    """
+    Thai MaiYaMok
+
+    MaiYaMok (ๆ) is the mark of duplicate word in Thai language.
+    This function is preprocessing MaiYaMok in Thai sentence.
+
+    :param Union[str, List[str]] sent: input sentence (list or str)
+    :return: List of words
+    :rtype: List[str]
+
+    :Example:
+    ::
+
+        from pythainlp.util import maiyamok
+
+        maiyamok("เด็กๆชอบไปโรงเรียน")
+        # output: ['เด็ก', 'เด็ก', 'ชอบ', 'ไป', 'โรงเรียน']
+
+        maiyamok(["ทำไม","คน","ดี"," ","ๆ","ๆ"," ","ถึง","ทำ","ไม่ได้"])
+        # output: ['ทำไม', 'คน', 'ดี', 'ดี', 'ดี', ' ', 'ถึง', 'ทำ', 'ไม่ได้']
+    """
+    if isinstance(sent, str):
+        sent = word_tokenize(sent)
+    _list_word = []
+    i = 0
+    for j, text in enumerate(sent):
+        if text.isspace() and "ๆ" in sent[j+1]:
+            continue
+        if " ๆ" in text:
+            text = text.replace(" ๆ", "ๆ")
+        if "ๆ" == text:
+            text = _list_word[i-1]
+        elif "ๆ" in text:
+            text = text.replace("ๆ", "")
+            _list_word.append(text)
+            i += 1
+        _list_word.append(text)
+        i += 1
+    return _list_word
