@@ -19,6 +19,7 @@ from pythainlp.util import (
     dict_trie,
     display_thai_char,
     digit_to_text,
+    emoji_to_thai,
     eng_to_thai,
     find_keyword,
     is_native_thai,
@@ -27,6 +28,7 @@ from pythainlp.util import (
     normalize,
     now_reign_year,
     num_to_thaiword,
+    maiyamok,
     rank,
     reign_year_to_ad,
     remove_dangling,
@@ -43,6 +45,9 @@ from pythainlp.util import (
     time_to_thaiword,
     thai_to_eng,
     thaiword_to_num,
+    thai_keyboard_dist,
+    text_to_num,
+    words_to_num,
 )
 
 
@@ -105,6 +110,40 @@ class TestUtilPackage(unittest.TestCase):
         with self.assertRaises(TypeError):
             thaiword_to_num(["หนึ่ง"])
 
+        self.assertEqual(words_to_num("ศูนย์"), 0)
+        self.assertEqual(words_to_num("แปด"), 8)
+        self.assertEqual(words_to_num("ยี่สิบ"), 20)
+        self.assertEqual(words_to_num("ร้อยสิบสอง"), 112)
+        self.assertEqual(words_to_num("ลบแปด"), -8)
+        self.assertEqual(words_to_num("ลบยี่สิบ"), -20)
+        self.assertEqual(words_to_num("ลบร้อยสิบสอง"), -112)
+        self.assertEqual(
+            words_to_num("หกล้านหกแสนหกหมื่นหกพันหกร้อยหกสิบหก"), 6666666
+        )
+        self.assertEqual(words_to_num("สองล้านสามแสนหกร้อยสิบสอง"), 2300612)
+        self.assertEqual(words_to_num("หนึ่งร้อยสิบล้าน"), 110000000)
+        self.assertEqual(
+            words_to_num("สิบห้าล้านล้านเจ็ดสิบสอง"), 15000000000072
+        )
+        self.assertEqual(words_to_num("หนึ่งล้านล้าน"), 1000000000000)
+        self.assertEqual(
+            words_to_num("สองแสนสี่หมื่นสามสิบล้านสี่พันล้าน"),
+            240030004000000000,
+        )
+        self.assertEqual(words_to_num("ร้อยสิบล้านแปดแสนห้าพัน"), 110805000)
+        self.assertEqual(words_to_num("ลบหนึ่ง"), -1)
+        text = "ลบหนึ่งร้อยล้านสี่แสนห้าพันยี่สิบเอ็ด"
+        self.assertEqual(num_to_thaiword(words_to_num(text)), text)
+        self.assertIsNotNone(
+            text_to_num("เก้าร้อยแปดสิบจุดเก้าห้าบาทนี่คือจำนวนทั้งหมด")
+        )
+        self.assertIsNotNone(
+            text_to_num("สิบล้านสองหมื่นหนึ่งพันแปดร้อยแปดสิบเก้าบาท")
+        )
+        self.assertIsNotNone(
+            text_to_num("สิบล้านสองหมื่นหนึ่งพันแปดร้อยแปดสิบเก้า")
+        )
+
         self.assertEqual(
             arabic_digit_to_thai_digit("ไทยแลนด์ 4.0"), "ไทยแลนด์ ๔.๐"
         )
@@ -156,6 +195,19 @@ class TestUtilPackage(unittest.TestCase):
             rank(["แมว", "คน", "แมว"], exclude_stopwords=True)
         )
 
+    # ### pythainlp.util.keyboard
+
+    def test_thai_keyboard_dist(self):
+        self.assertEqual(thai_keyboard_dist("ฟ", "ฤ"), 0.0)
+        self.assertEqual(thai_keyboard_dist("ฟ", "ห"), 1.0)
+        self.assertEqual(thai_keyboard_dist("ฟ", "ก"), 2.0)
+        self.assertEqual(thai_keyboard_dist("ฟ", "ฤ", 0.5), 0.5)
+        self.assertNotEqual(
+            thai_keyboard_dist("๘", "๙"), thai_keyboard_dist("๙", "๐")
+        )
+        with self.assertRaises(ValueError):
+            thai_keyboard_dist("ພ","พ")
+
     # ### pythainlp.util.date
 
     def test_date(self):
@@ -237,7 +289,8 @@ class TestUtilPackage(unittest.TestCase):
             time_to_thaiword(time(12, 3, 0)), "สิบสองนาฬิกาสามนาที"
         )
         self.assertEqual(
-            time_to_thaiword(time(12, 3, 1)), "สิบสองนาฬิกาสามนาทีหนึ่งวินาที",
+            time_to_thaiword(time(12, 3, 1)),
+            "สิบสองนาฬิกาสามนาทีหนึ่งวินาที",
         )
         self.assertEqual(
             time_to_thaiword(datetime(2014, 5, 22, 12, 3, 0), precision="s"),
@@ -352,13 +405,16 @@ class TestUtilPackage(unittest.TestCase):
             now + timedelta(days=0), thaiword_to_date("วันนี้", now)
         )
         self.assertEqual(
-            now + timedelta(days=1), thaiword_to_date("พรุ่งนี้", now),
+            now + timedelta(days=1),
+            thaiword_to_date("พรุ่งนี้", now),
         )
         self.assertEqual(
-            now + timedelta(days=2), thaiword_to_date("มะรืนนี้", now),
+            now + timedelta(days=2),
+            thaiword_to_date("มะรืนนี้", now),
         )
         self.assertEqual(
-            now + timedelta(days=-1), thaiword_to_date("เมื่อวาน", now),
+            now + timedelta(days=-1),
+            thaiword_to_date("เมื่อวาน", now),
         )
         self.assertEqual(
             now + timedelta(days=-2), thaiword_to_date("วานซืน", now)
@@ -477,6 +533,57 @@ class TestUtilPackage(unittest.TestCase):
         self.assertEqual(remove_zw("\u200bกา"), "กา")
         self.assertEqual(remove_zw("กา\u200b\u200c\u200b"), "กา")
 
+        # maiyamok
+        self.assertEqual(
+            maiyamok("เด็กๆชอบไปโรงเรียน"),
+            ['เด็ก', 'เด็ก', 'ชอบ', 'ไป', 'โรงเรียน']
+        )
+        self.assertEqual(
+            maiyamok([
+                "ทำไม",
+                "คน",
+                "ดี",
+                " ",
+                "ๆ",
+                "ๆ",
+                " ",
+                "ถึง",
+                "ทำ",
+                "ไม่ได้"
+            ]),
+            ["ทำไม", "คน", "ดี", "ดี", "ดี", " ", "ถึง", "ทำ", "ไม่ได้"]
+        )
+        self.assertEqual(
+            maiyamok([
+                "ทำไม",
+                "คน",
+                "ดี",
+                " ",
+                " ๆ",
+                "ๆ",
+                " ",
+                "ถึง",
+                "ทำ",
+                "ไม่ได้"
+            ]),
+            ["ทำไม", "คน", "ดี", "ดี", "ดี", " ", "ถึง", "ทำ", "ไม่ได้"]
+        )
+        self.assertEqual(
+            maiyamok([
+                "ทำไม",
+                "คน",
+                "ดีๆ",
+                " ",
+                "ๆ",
+                "ๆ",
+                " ",
+                "ถึง",
+                "ทำ",
+                "ไม่ได้"
+            ]),
+            ["ทำไม", "คน", "ดี", "ดี", "ดี", "ดี", " ", "ถึง", "ทำ", "ไม่ได้"]
+        )
+
     # ### pythainlp.util.thai
 
     def test_countthai(self):
@@ -529,3 +636,24 @@ class TestUtilPackage(unittest.TestCase):
         self.assertEqual(display_thai_char("ำ"), "_ำ")
         self.assertEqual(display_thai_char("๎"), "_๎")
         self.assertEqual(display_thai_char("ํ"), "_ํ")
+
+    # ### pythainlp.util.emojiconv
+
+    def test_emoji_to_thai(self):
+        self.assertEqual(
+            emoji_to_thai(
+                "จะมานั่งรถเมล์เหมือนผมก็ได้นะครับ ใกล้ชิดประชาชนดี 😀"
+            ),
+            (
+                "จะมานั่งรถเมล์เหมือนผมก็ได้นะครับ "
+                "ใกล้ชิดประชาชนดี :หน้ายิ้มยิงฟัน:"
+            ),
+        )
+        self.assertEqual(
+            emoji_to_thai("หิวข้าวอยากกินอาหารญี่ปุ่น 🍣"),
+            "หิวข้าวอยากกินอาหารญี่ปุ่น :ซูชิ:",
+        )
+        self.assertEqual(
+            emoji_to_thai("🇹🇭 นี่คือธงประเทศไทย"),
+            ":ธง_ไทย: นี่คือธงประเทศไทย",
+        )
